Documentation
¶
Index ¶
- type AppModule
- func (am AppModule) AutoCLIOptions() *autocliv1.ModuleOptions
- func (AppModule) ConsensusVersion() uint64
- func (am AppModule) ExportGenesis(ctx sdk.Context, cdc codec.JSONCodec) json.RawMessage
- func (am AppModule) GenerateGenesisState(simState *module.SimulationState)
- func (am AppModule) InitGenesis(ctx sdk.Context, cdc codec.JSONCodec, data json.RawMessage)
- func (am AppModule) IsAppModule()
- func (am AppModule) IsOnePerModuleType()
- func (am AppModule) RegisterServices(registrar grpc.ServiceRegistrar) error
- func (am AppModule) RegisterStoreDecoder(sdr simtypes.StoreDecoderRegistry)
- func (am AppModule) WeightedOperations(simState module.SimulationState) []simtypes.WeightedOperation
- func (am AppModule) WeightedOperationsX(weights simsx.WeightSource, reg simsx.Registry)
- type AppModuleBasic
- func (AppModuleBasic) DefaultGenesis(cdc codec.JSONCodec) json.RawMessage
- func (AppModuleBasic) Name() string
- func (AppModuleBasic) RegisterGRPCGatewayRoutes(clientCtx sdkclient.Context, mux *gwruntime.ServeMux)
- func (AppModuleBasic) RegisterInterfaces(registry cdctypes.InterfaceRegistry)
- func (AppModuleBasic) RegisterLegacyAminoCodec(cdc *codec.LegacyAmino)
- func (ab AppModuleBasic) ValidateGenesis(cdc codec.JSONCodec, config sdkclient.TxEncodingConfig, bz json.RawMessage) error
- type NftInputs
- type NftOutputs
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppModule ¶
type AppModule struct {
AppModuleBasic
// contains filtered or unexported fields
}
AppModule implements the sdk.AppModule interface
func NewAppModule ¶
func NewAppModule(cdc codec.Codec, keeper keeper.Keeper, ak nft.AccountKeeper, bk nft.BankKeeper, registry cdctypes.InterfaceRegistry) AppModule
NewAppModule creates a new AppModule object
func (AppModule) AutoCLIOptions ¶
func (am AppModule) AutoCLIOptions() *autocliv1.ModuleOptions
AutoCLIOptions implements the autocli.HasAutoCLIConfig interface.
func (AppModule) ConsensusVersion ¶
ConsensusVersion implements AppModule/ConsensusVersion.
func (AppModule) ExportGenesis ¶
ExportGenesis returns the exported genesis state as raw bytes for the nft module.
func (AppModule) GenerateGenesisState ¶
func (am AppModule) GenerateGenesisState(simState *module.SimulationState)
GenerateGenesisState creates a randomized GenState of the nft module.
func (AppModule) InitGenesis ¶
InitGenesis performs genesis initialization for the nft module. It returns no validator updates.
func (AppModule) IsAppModule ¶
func (am AppModule) IsAppModule()
IsAppModule implements the appmodule.AppModule interface.
func (AppModule) IsOnePerModuleType ¶
func (am AppModule) IsOnePerModuleType()
IsOnePerModuleType implements the depinject.OnePerModuleType interface.
func (AppModule) RegisterServices ¶
func (am AppModule) RegisterServices(registrar grpc.ServiceRegistrar) error
RegisterServices registers a gRPC query service to respond to the module-specific gRPC queries.
func (AppModule) RegisterStoreDecoder ¶
func (am AppModule) RegisterStoreDecoder(sdr simtypes.StoreDecoderRegistry)
RegisterStoreDecoder registers a decoder for nft module's types
func (AppModule) WeightedOperations ¶
func (am AppModule) WeightedOperations(simState module.SimulationState) []simtypes.WeightedOperation
WeightedOperations returns the all the nft module operations with their respective weights. migrate to WeightedOperationsX. This method is ignored when WeightedOperationsX exists and will be removed in the future
func (AppModule) WeightedOperationsX ¶ added in v0.2.0
func (am AppModule) WeightedOperationsX(weights simsx.WeightSource, reg simsx.Registry)
WeightedOperationsX registers weighted nft module operations for simulation.
type AppModuleBasic ¶
type AppModuleBasic struct {
// contains filtered or unexported fields
}
AppModuleBasic defines the basic application module used by the nft module.
func (AppModuleBasic) DefaultGenesis ¶
func (AppModuleBasic) DefaultGenesis(cdc codec.JSONCodec) json.RawMessage
DefaultGenesis returns default genesis state as raw bytes for the nft module.
func (AppModuleBasic) Name ¶
func (AppModuleBasic) Name() string
Name returns the nft module's name.
func (AppModuleBasic) RegisterGRPCGatewayRoutes ¶
func (AppModuleBasic) RegisterGRPCGatewayRoutes(clientCtx sdkclient.Context, mux *gwruntime.ServeMux)
RegisterGRPCGatewayRoutes registers the gRPC Gateway routes for the nft module.
func (AppModuleBasic) RegisterInterfaces ¶
func (AppModuleBasic) RegisterInterfaces(registry cdctypes.InterfaceRegistry)
RegisterInterfaces registers the nft module's interface types
func (AppModuleBasic) RegisterLegacyAminoCodec ¶
func (AppModuleBasic) RegisterLegacyAminoCodec(cdc *codec.LegacyAmino)
RegisterLegacyAminoCodec registers the nft module's types for the given codec.
func (AppModuleBasic) ValidateGenesis ¶
func (ab AppModuleBasic) ValidateGenesis(cdc codec.JSONCodec, config sdkclient.TxEncodingConfig, bz json.RawMessage) error
ValidateGenesis performs genesis state validation for the nft module.
type NftInputs ¶
type NftInputs struct {
depinject.In
StoreService store.KVStoreService
Cdc codec.Codec
Registry cdctypes.InterfaceRegistry
AccountKeeper nft.AccountKeeper
BankKeeper nft.BankKeeper
}
type NftOutputs ¶
func ProvideModule ¶
func ProvideModule(in NftInputs) NftOutputs